@@ -4,12 +4,12 @@ use warnings;
 package PBKDF2::Tiny;
 # ABSTRACT: Minimalist PBKDF2 (RFC 2898) with HMAC-SHA1 or HMAC-SHA2
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Carp ();
 use Exporter 5.57 qw/import/;
 
-our @EXPORT_OK = qw/derive derive_hex verify verify_hex/;
+our @EXPORT_OK = qw/derive derive_hex verify verify_hex hmac digest_fcn/;
 
 my ( $BACKEND, $LOAD_ERR );
 for my $mod (qw/Digest::SHA Digest::SHA::PurePerl/) {
@@ -214,7 +214,7 @@ PBKDF2::Tiny - Minimalist PBKDF2 (RFC 2898) with HMAC-SHA1 or HMAC-SHA2
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -234,6 +234,8 @@ of code.  If you are using Perl 5.10 or later, it uses only core Perl modules.
 If you are on an earlier version of Perl, you need L<Digest::SHA> or
 L<Digest::SHA::PurePerl>.
 
+All documented functions are optionally exported.  No functions are exported by default.
+
 =head1 FUNCTIONS
 
 =head2 derive
